@@ -19,30 +19,14 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <KLocalizedString>
-#include <QDebug>
-#if QT_VERSION < 0x050500
-# define qInfo qDebug
-#endif
+#include "../log.h"
 
 extern "C" {
-  #include <dirent.h>
   #include <dmx.h>
   #include <errno.h>
   #include <fcntl.h>
   #include <frontend.h>
   #include <poll.h>
-  #include <stdlib.h>
-  #include <sys/syslog.h>
-  #include <unistd.h>
-  #include <vector>
-  #include <sys/socket.h>
-  #include <sys/un.h>
-  #include <sys/types.h>
-  #include <sys/inotify.h>
-  #include <sys/ioctl.h>
-  #include <sys/stat.h>
-  #include <sys/syslog.h>
 }
 
 #include <QFile>
@@ -59,7 +43,7 @@ extern "C" {
 DvbLinuxDevice::DvbLinuxDevice(QObject *parent) : QThread(parent), ready(false), frontend(NULL),
 	enabled(false), dvrFd(-1), dvrBuffer(NULL, 0), cam(parent)
 {
-	verbose = 0;
+	verbose = 1;
 	numDemux = 0;
 	dvrPipe[0] = -1;
 	dvrPipe[1] = -1;
@@ -82,19 +66,19 @@ static void dvbv5_log(int level, const char *fmt, ...)
 	switch(LOG_PRI(level)) {
 	case LOG_DEBUG:
 	case LOG_INFO:
-		qDebug("%s", log);
+		qCDebug(logDev, "%s", log);
 		break;
 	case LOG_NOTICE:
-		qInfo("%s", log);
+		qCInfo(logDev, "%s", log);
 		break;
 	case LOG_WARNING:
-		qWarning("%s", log);
+		qCWarning(logDev, "%s", log);
 		break;
 	case LOG_ERR:
 	case LOG_CRIT:
 	case LOG_ALERT:
 	case LOG_EMERG:
-		qCritical("%s", log);
+		qCCritical(logDev, "%s", log);
 		break;
 	}
 }
@@ -110,7 +94,7 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 	struct dvb_v5_fe_parms *parms = dvb_fe_open2(adapter, index, verbose, 0, dvbv5_log);
 
 	if (!parms) {
-		qWarning("Cannot open frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "Cannot open frontend %s", qPrintable(frontendPath));
 		return;
 	}
 
@@ -141,7 +125,7 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 			transmissionTypes |= IsdbT;
 			break;
 		default: /* not supported yet */
-			qWarning("Unsupported transmission type: %d", parms->systems[i]);
+			qCWarning(logDev, "Unsupported transmission type: %d", parms->systems[i]);
 			break;
 		}
 	}
@@ -199,7 +183,7 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 
 	ready = true;
 
-	qInfo("Found dvb device %s: %s", qPrintable(deviceId), qPrintable(frontendName));
+	qCInfo(logDev, "Found dvb device %s: %s", qPrintable(deviceId), qPrintable(frontendName));
 }
 
 void DvbLinuxDevice::startCa()
@@ -279,14 +263,14 @@ bool DvbLinuxDevice::acquire()
 	dvbv5_parms = dvb_fe_open2(adapter, index, verbose, 0, dvbv5_log);
 
 	if (!dvbv5_parms) {
-		qWarning("Cannot open frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "Cannot open frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
 	dvrFd = open(QFile::encodeName(dvrPath).constData(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 
 	if (dvrFd < 0) {
-		qWarning("Cannot open dvr %s", qPrintable(dvrPath));
+		qCWarning(logDev, "Cannot open dvr %s", qPrintable(dvrPath));
 		dvb_fe_close(dvbv5_parms);
 		dvbv5_parms = NULL;
 		return false;
@@ -301,7 +285,7 @@ bool DvbLinuxDevice::setTone(SecTone tone)
 
 	if (dvb_fe_sec_tone(dvbv5_parms,
 		  (tone == ToneOn) ? SEC_TONE_ON : SEC_TONE_OFF) != 0) {
-		qWarning("ioctl FE_SET_TONE failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_SET_TONE failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -313,7 +297,7 @@ bool DvbLinuxDevice::setVoltage(SecVoltage voltage)
 	Q_ASSERT(dvbv5_parms);
 
 	if (dvb_fe_lnb_high_voltage(dvbv5_parms, voltage == Voltage18V) != 0) {
-		qWarning("ioctl FE_SET_VOLTAGE failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_SET_VOLTAGE failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -325,7 +309,7 @@ bool DvbLinuxDevice::sendMessage(const char *message, int length)
 	Q_ASSERT(dvbv5_parms && (length >= 0) && (length <= 6));
 
 	if (dvb_fe_diseqc_cmd(dvbv5_parms, length, (const unsigned char *)message) != 0) {
-		qWarning("ioctl FE_DISEQC_SEND_MASTER_CMD failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_DISEQC_SEND_MASTER_CMD failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -337,7 +321,7 @@ bool DvbLinuxDevice::sendBurst(SecBurst burst)
 	Q_ASSERT(dvbv5_parms);
 
 	if (dvb_fe_diseqc_burst(dvbv5_parms, burst == BurstMiniB) != 0) {
-		qWarning("ioctl FE_DISEQC_SEND_BURST failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_DISEQC_SEND_BURST failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -912,7 +896,7 @@ bool DvbLinuxDevice::satSetup(QString lnbModel, int satNumber, int bpf)
 	int lnb = dvb_sat_search_lnb(lnbModel.toUtf8());
 	dvbv5_parms->lnb = dvb_sat_get_lnb(lnb);
 	if (!dvbv5_parms->lnb) {
-		qCritical("Cannot set LNBf type to %s", qPrintable(lnbModel));
+		qCCritical(logDev, "Cannot set LNBf type to %s", qPrintable(lnbModel));
 		return false;
 	}
 
@@ -1086,15 +1070,15 @@ bool DvbLinuxDevice::tune(const DvbTransponder &transponder)
 		break;
 	    }
 	case DvbTransponderBase::Invalid:
-		qWarning("Invalid transmission type");
+		qCWarning(logDev, "Invalid transmission type");
 		return false;
 	default:
-		qWarning("Unknown transmission type %d", transponder.getTransmissionType());
+		qCWarning(logDev, "Unknown transmission type %d", transponder.getTransmissionType());
 		return false;
 	}
 
 	if (dvb_fe_set_parms(dvbv5_parms) != 0) {
-		qWarning("ioctl FE_SET_PROPERTY failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_SET_PROPERTY failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -1269,10 +1253,10 @@ bool DvbLinuxDevice::getProps(DvbTransponder &transponder)
 		break;
 	    }
 	case DvbTransponderBase::Invalid:
-		qWarning("Invalid transmission type");
+		qCWarning(logDev, "Invalid transmission type");
 		return false;
 	default:
-		qWarning("Unknown transmission type %s", qPrintable(transponder.getTransmissionType()));
+		qCWarning(logDev, "Unknown transmission type %s", qPrintable(transponder.getTransmissionType()));
 		return false;
 	}
 	return true;
@@ -1297,12 +1281,12 @@ bool DvbLinuxDevice::isTuned()
 	uint32_t status = 0;
 
 	if (dvb_fe_get_stats(dvbv5_parms) != 0) {
-		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
 	if (dvb_fe_retrieve_stats(dvbv5_parms, DTV_STATUS, &status) != 0) {
-		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -1318,7 +1302,7 @@ float DvbLinuxDevice::getSignal(Scale &scale)
 	scale = DvbBackendDevice::NotSupported;
 
 	if (dvb_fe_get_stats(dvbv5_parms) != 0) {
-		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -1361,7 +1345,7 @@ float DvbLinuxDevice::getSnr(Scale &scale)
 
 	scale = DvbBackendDevice::NotSupported;
 	if (dvb_fe_get_stats(dvbv5_parms) != 0) {
-		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
+		qCWarning(logDev, "ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -1400,14 +1384,14 @@ bool DvbLinuxDevice::addPidFilter(int pid)
 	Q_ASSERT(frontendFd >= 0);
 
 	if (dmxFds.contains(pid)) {
-		qWarning("PID filter already set up for pid %d", pid);
+		qCWarning(logDev, "PID filter already set up for pid %d", pid);
 		return false;
 	}
 
 	int dmxFd = open(QFile::encodeName(demuxPath).constData(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 
 	if (dmxFd < 0) {
-		qWarning("Cannot open demux %s", qPrintable(demuxPath));
+		qCWarning(logDev, "Cannot open demux %s", qPrintable(demuxPath));
 		return false;
 	}
 
@@ -1420,7 +1404,7 @@ bool DvbLinuxDevice::addPidFilter(int pid)
 	pes_filter.flags = DMX_IMMEDIATE_START;
 
 	if (ioctl(dmxFd, DMX_SET_PES_FILTER, &pes_filter) != 0) {
-		qWarning("Cannot set up PID filter for demux %s", qPrintable(demuxPath));
+		qCWarning(logDev, "Cannot set up PID filter for demux %s", qPrintable(demuxPath));
 		close(dmxFd);
 		return false;
 	}
@@ -1434,7 +1418,7 @@ void DvbLinuxDevice::removePidFilter(int pid)
 	Q_ASSERT(frontendFd >= 0);
 
 	if (!dmxFds.contains(pid)) {
-		qWarning("No PID filter set up for PID %i", pid);
+		qCWarning(logDev, "No PID filter set up for PID %i", pid);
 		return;
 	}
 
@@ -1499,7 +1483,7 @@ void DvbLinuxDevice::startDvr()
 		}
 
 		if ((dvrPipe[0] < 0) || (dvrPipe[1] < 0)) {
-			qCritical("Cannot create pipe");
+			qCCritical(logDev, "Cannot create pipe");
 			return;
 		}
 	}
@@ -1532,7 +1516,7 @@ void DvbLinuxDevice::startDvr()
 					continue;
 				}
 
-				qWarning("Cannot read from dvr %s: error: %d", qPrintable(dvrPath), errno);
+				qCWarning(logDev, "Cannot read from dvr %s: error: %d", qPrintable(dvrPath), errno);
 				return;
 			}
 		}
@@ -1551,14 +1535,14 @@ void DvbLinuxDevice::stopDvr()
 		Q_ASSERT((dvrPipe[0] >= 0) && (dvrPipe[1] >= 0));
 
 		if (write(dvrPipe[1], " ", 1) != 1) {
-			qWarning("Cannot write to pipe");
+			qCWarning(logDev, "Cannot write to pipe");
 		}
 
 		wait();
 		char data;
 
 		if (read(dvrPipe[0], &data, 1) != 1) {
-			qWarning("Cannot read from pipe");
+			qCWarning(logDev, "Cannot read from pipe");
 		}
 	}
 }
@@ -1579,7 +1563,7 @@ void DvbLinuxDevice::run()
 				continue;
 			}
 
-			qWarning("Poll failed with error: %d", errno);
+			qCWarning(logDev, "Poll failed with error: %d", errno);
 			return;
 		}
 
@@ -1600,7 +1584,7 @@ void DvbLinuxDevice::run()
 					continue;
 				}
 
-				qWarning("Cannot read from dvr %s: error %d", qPrintable(dvrPath), errno);
+				qCWarning(logDev, "Cannot read from dvr %s: error %d", qPrintable(dvrPath), errno);
 				dataSize = int(read(dvrFd, dvrBuffer.data, bufferSize));
 
 				if (dataSize < 0) {
@@ -1612,7 +1596,7 @@ void DvbLinuxDevice::run()
 						continue;
 					}
 
-					qWarning("Cannot read from dvr %s: error %d", qPrintable(dvrPath), errno);
+					qCWarning(logDev, "Cannot read from dvr %s: error %d", qPrintable(dvrPath), errno);
 					return;
 				}
 			}
@@ -1632,181 +1616,15 @@ void DvbLinuxDevice::run()
 	}
 }
 
-struct dvbdev {
-	time_t stctime;
-	char checked;
-	char adapter_name[50];
-	char node_name[75];
-	int adapternum;
-	char lnode[20];
-};
-
-class DvbDeviceMonitor : public QThread
-{
-	public:
-		DvbDeviceMonitor(DvbLinuxDeviceManager *ddm)
-		{
-			this->ddm = ddm;
-		}
-		~DvbDeviceMonitor()
-		{
-		}
-		void run() {
-			DIR *dvbdir, *adapterdirp;
-			struct dirent *dp, *dp2;
-			struct stat stbuf;
-			int adapter;
-			int rescan=0;
-			int rv;
-			int ifd;
-			int found=0;
-			char adapterdir[50];
-			char nodename[75];
-			char buffer[1024];
-			struct pollfd pfd;
-			char firstrun_complete=0;
-			std::vector<struct dvbdev*>adapterlist;
-			std::vector<struct dvbdev*>::iterator iter;
-
-			runstate = 1;
-
-			ifd = inotify_init();
-			inotify_add_watch(ifd, "/dev/dvb", IN_CREATE|IN_DELETE);
-			fcntl(ifd, F_SETFL, O_NONBLOCK);
-			pfd.fd = ifd;
-			pfd.events = POLLIN;
-
-			while(runstate) {
-				if (firstrun_complete) {
-					rv = poll(&pfd, 1, 100);
-					switch (rv) {
-						case -1:
-							break;
-						case 0:
-							continue;
-						default:
-							usleep(100000); /* give it some time to settle down */
-							while(read(ifd, buffer, 1024)>0);
-							break;
-					}
-				} else {
-					firstrun_complete=1;
-				}
-
-				dvbdir = opendir("/dev/dvb");
-				for (iter=adapterlist.begin();iter!=adapterlist.end();iter++) {
-					(*iter)->checked=0;
-				}
-				if (dvbdir) {
-					while((dp=readdir(dvbdir))!= 0) {
-						if (strcmp(dp->d_name, ".") == 0 ||
-								strcmp(dp->d_name, "..") == 0)
-							continue;
-						adapter = strtol(&dp->d_name[7], NULL, 10);
-						sprintf(adapterdir, "/dev/dvb/%s", dp->d_name);
-						adapterdirp = opendir(adapterdir);
-						if (adapterdirp) {
-							while((dp2=readdir(adapterdirp))!=0) {
-								found=0;
-								if (strcmp(dp2->d_name, ".")==0 ||
-										strcmp(dp2->d_name, "..")==0)
-									continue;
-								sprintf(nodename, "/dev/dvb/%s/%s", dp->d_name, dp2->d_name);
-								rv = stat(nodename, &stbuf);
-								for (iter=adapterlist.begin();iter!=adapterlist.end();iter++) {
-									if (strcmp((*iter)->node_name, nodename)==0 && (*iter)->stctime == stbuf.st_ctime) {
-										(*iter)->checked=1;
-										found=1;
-										break;
-									}
-								}
-								if (found == 0) {
-									struct dvbdev *dvbdev = (struct dvbdev*)calloc(1, sizeof(struct dvbdev));
-									dvbdev->checked=1;
-									dvbdev->stctime = stbuf.st_ctime;
-									strcpy(dvbdev->adapter_name, dp->d_name);
-									strcpy(dvbdev->node_name, nodename);
-									dvbdev->adapternum = adapter;
-									strcpy(dvbdev->lnode, dp2->d_name);
-									adapterlist.push_back(dvbdev);
-									ddm->componentAdded(dp2->d_name, adapter, 0);
-								}
-
-							}
-							closedir(adapterdirp);
-						}
-					}
-					closedir(dvbdir);
-				}
-				do {
-					rescan=0;
-					for (iter=adapterlist.begin();iter!=adapterlist.end();iter++) {
-						if ((*iter)->checked==0) {
-							ddm->componentRemoved((*iter)->lnode, (*iter)->adapternum, 0);
-							free(*iter);
-							adapterlist.erase(iter);
-							rescan=1;
-							break;
-						}
-					}
-				} while (rescan!=0);
-			}
-		}
-		void stop() {
-			runstate = 0;
-			wait();
-		}
-	private:
-		int runstate;
-		DvbLinuxDeviceManager *ddm;
-};
-
-#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun)
-#define MACHADDRESS "/tmp/.mediasocket"
-#else
-#define ADDRESS     "/de/sundtek/mediasocket"  /* addr to connect */
-#endif
-
 DvbLinuxDeviceManager::DvbLinuxDeviceManager(QObject *parent) : QObject(parent)
 {
-	int fd;
-	int len;
-	int ret;
-	struct sockaddr_un saun;
 	QObject *notifier = Solid::DeviceNotifier::instance();
 	connect(notifier, SIGNAL(deviceAdded(QString)), this, SLOT(componentAdded(QString)));
 	connect(notifier, SIGNAL(deviceRemoved(QString)), this, SLOT(componentRemoved(QString)));
-
-	memset(&saun, 0x0, sizeof(struct sockaddr_un));
-	fd = socket(AF_UNIX, SOCK_STREAM, 0);
-	if (fd==-1) {
-		monitor = NULL;
-		return;
-	}
-	saun.sun_family = AF_UNIX;
-#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun)
-	strcpy(saun.sun_path, MACHADDRESS);
-	len = sizeof(saun.sun_family) + strlen(saun.sun_path)+1;
-#else
-	strcpy(&saun.sun_path[1], ADDRESS);
-	len = sizeof(saun.sun_family) + strlen(&saun.sun_path[1])+1;
-#endif
-	if ((ret=::connect(fd, (struct sockaddr*)&saun, len)) < 0) {
-		close(fd);
-		monitor = NULL;
-		return;
-	}
-	close(fd);
-	qInfo("Starting DvbDeviceMonitor thread");
-
-	monitor = new DvbDeviceMonitor(this);
-	monitor->start();
 }
 
 DvbLinuxDeviceManager::~DvbLinuxDeviceManager()
 {
-	if (monitor)
-		monitor->stop();
 }
 
 void DvbLinuxDeviceManager::doColdPlug()
@@ -1816,51 +1634,6 @@ void DvbLinuxDeviceManager::doColdPlug()
 	}
 }
 
-void
-DvbLinuxDeviceManager::componentAdded (QString node, int adapter, int index)
-{
-	int deviceIndex = (adapter << 16) | index;
-	char adapterstring[10];
-	DvbLinuxDevice *device = devices.value (deviceIndex, NULL);
-	if (device == NULL)
-	{
-		device = new DvbLinuxDevice (this);
-		devices.insert (deviceIndex, device);
-	}
-	sprintf (adapterstring, "adapter%d", adapter);
-
-	if (node == "frontend0")
-	{
-		device->frontendPath.sprintf ("/dev/dvb/%s/%s", adapterstring,
-				node.toStdString().c_str());
-	}
-	else if (node == "dvr0")
-	{
-		device->dvrPath.sprintf ("/dev/dvb/%s/%s", adapterstring,
-				node.toStdString().c_str());
-	}
-	else if (node == "demux0")
-	{
-		device->demuxPath.sprintf ("/dev/dvb/%s/%s", adapterstring,
-				node.toStdString().c_str());
-	}
-	else
-	{
-		return;
-	}
-
-	if (!device->demuxPath.isEmpty () && !device->dvrPath.isEmpty () &&
-			!device->frontendPath.isEmpty ())
-	{
-		device->startDevice ("");
-
-		if (device->isReady ())
-		{
-			emit deviceAdded (device);
-		}
-	}
-}
-
 void DvbLinuxDeviceManager::componentAdded(const QString &udi)
 {
 	QRegularExpressionMatch match;
@@ -1881,12 +1654,12 @@ void DvbLinuxDeviceManager::componentAdded(const QString &udi)
 	QString devicePath = QString(QLatin1String("/dev/dvb/adapter%1/%2%3")).arg(adapter).arg(type).arg(index);
 
 	if ((adapter < 0) || (adapter > 0x7fff) || (index < 0) || (index > 0x7fff)) {
-		qWarning("Cannot determine adapter or index for device %s", qPrintable(udi));
+		qCWarning(logDev, "Cannot determine adapter or index for device %s", qPrintable(udi));
 		return;
 	}
 
 	if (devicePath.isEmpty()) {
-		qWarning("Cannot determine path for device %s", qPrintable(udi));
+		qCWarning(logDev, "Cannot determine path for device %s", qPrintable(udi));
 		return;
 	}
 
@@ -2038,7 +1811,7 @@ void DvbLinuxDeviceManager::componentRemoved(const QString &udi)
 	bool removeDevice = false;
 
 	if (device->isReady())
-		qInfo("Digital TV device removed %s: %s", qPrintable(device->getDeviceId()), qPrintable(device->getFrontendName()));
+		qCInfo(logDev, "Digital TV device removed %s: %s", qPrintable(device->getDeviceId()), qPrintable(device->getFrontendName()));
 
 	if (udi == device->caUdi) {
 		device->caPath.clear();
