@@ -306,8 +306,6 @@ void MainWindow::run()
 	mediaWidget = new MediaWidget(playerMenu, controlBar, collection, widget);
 	connect(mediaWidget, SIGNAL(displayModeChanged()), this, SLOT(displayModeChanged()));
 	connect(mediaWidget, SIGNAL(changeCaption(QString)), this, SLOT(setWindowTitle(QString)));
-	connect(mediaWidget, SIGNAL(resizeToVideo(MediaWidget::ResizeFactor)),
-		this, SLOT(resizeToVideo(MediaWidget::ResizeFactor)));
 
 	// tabs - keep in sync with TabIndex enum!
 
@@ -511,7 +509,7 @@ MainWindow::MainWindow(KAboutData *aboutData, QCommandLineParser *parser)
 	parser->addPositionalArgument(QLatin1String("[file]"), i18n("Files or URLs to play"));
 }
 
-void MainWindow::parseArgs()
+void MainWindow::parseArgs(const QString workingDirectory)
 {
 	if (parser->isSet("fullscreen")) {
 		mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
@@ -581,7 +579,7 @@ void MainWindow::parseArgs()
 		QList<QUrl> urls;
 
 		for (int i = 0; i < parser->positionalArguments().count(); ++i) {
-			QUrl url = QUrl::fromUserInput(parser->positionalArguments().at(i));
+			QUrl url = QUrl::fromUserInput(parser->positionalArguments().at(i), workingDirectory);
 
 			if (url.isValid()) {
 				urls.append(url);
@@ -738,32 +736,6 @@ void MainWindow::playDvb()
 	dvbTab->playLastChannel();
 }
 
-void MainWindow::resizeToVideo(MediaWidget::ResizeFactor resizeFactor)
-{
-	if (!isFullScreen() && !mediaWidget->sizeHint().isEmpty()) {
-		if (isMaximized()) {
-			setWindowState(windowState() & ~Qt::WindowMaximized);
-		}
-
-		QSize videoSize;
-
-		switch (resizeFactor) {
-		case MediaWidget::ResizeOff:
-			break;
-		case MediaWidget::OriginalSize:
-			videoSize = mediaWidget->sizeHint();
-			break;
-		case MediaWidget::DoubleSize:
-			videoSize = (2 * mediaWidget->sizeHint());
-			break;
-		}
-
-		if (!videoSize.isEmpty()) {
-			resize(size() - centralWidget()->size() + videoSize);
-		}
-	}
-}
-
 void MainWindow::configureKeys()
 {
 	KShortcutsDialog::configure(collection);
