@@ -50,7 +50,7 @@
 
 MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *collection,
 	QWidget *parent) : QWidget(parent), menu(menu_), displayMode(NormalMode),
-	automaticResize(ResizeOff), blockBackendUpdates(false), muted(false),
+	autoResizeFactor(0), blockBackendUpdates(false), muted(false),
 	screenSaverSuspended(false), showElapsedTime(true)
 {
 	dummySource.reset(new MediaSource());
@@ -216,16 +216,25 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_auto"), action));
 
 	action = new QWidgetAction(aspectGroup);
-	action->setText(i18nc("'Aspect Ratio' menu", "Fit to Window"));
+	action->setText(i18nc("'Aspect Ratio' menu", "1:1"));
 	action->setCheckable(true);
-	action->setData(AspectRatioWidget);
-	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_widget"), action));
+	action->setData(AspectRatio1_1);
+	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_1_1"), action));
+	videoMenu->addMenu(aspectMenu);
 
 	action = new QWidgetAction(aspectGroup);
 	action->setText(i18nc("'Aspect Ratio' menu", "4:3"));
 	action->setCheckable(true);
 	action->setData(AspectRatio4_3);
 	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_4_3"), action));
+	videoMenu->addMenu(aspectMenu);
+
+	action = new QWidgetAction(aspectGroup);
+	action->setText(i18nc("'Aspect Ratio' menu", "5:4"));
+	action->setCheckable(true);
+	action->setData(AspectRatio5_4);
+	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_5_4"), action));
+	videoMenu->addMenu(aspectMenu);
 
 	action = new QWidgetAction(aspectGroup);
 	action->setText(i18nc("'Aspect Ratio' menu", "16:9"));
@@ -234,7 +243,35 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_16_9"), action));
 	videoMenu->addMenu(aspectMenu);
 
-	QMenu *autoResizeMenu = new QMenu(i18n("Automatic Resize"), this);
+	action = new QWidgetAction(aspectGroup);
+	action->setText(i18nc("'Aspect Ratio' menu", "16:10"));
+	action->setCheckable(true);
+	action->setData(AspectRatio16_10);
+	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_16_10"), action));
+	videoMenu->addMenu(aspectMenu);
+
+	action = new QWidgetAction(aspectGroup);
+	action->setText(i18nc("'Aspect Ratio' menu", "2.21:1"));
+	action->setCheckable(true);
+	action->setData(AspectRatio221_100);
+	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_221_100"), action));
+	videoMenu->addMenu(aspectMenu);
+
+	action = new QWidgetAction(aspectGroup);
+	action->setText(i18nc("'Aspect Ratio' menu", "2.35:1"));
+	action->setCheckable(true);
+	action->setData(AspectRatio235_100);
+	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_235_100"), action));
+	videoMenu->addMenu(aspectMenu);
+
+	action = new QWidgetAction(aspectGroup);
+	action->setText(i18nc("'Aspect Ratio' menu", "2.39:1"));
+	action->setCheckable(true);
+	action->setData(AspectRatio239_100);
+	aspectMenu->addAction(collection->addAction(QLatin1String("controls_aspect_239_100"), action));
+	videoMenu->addMenu(aspectMenu);
+
+	QMenu *autoResizeMenu = new QMenu(i18n("Video size"), this);
 	QActionGroup *autoResizeGroup = new QActionGroup(this);
 	// we need an event even if you select the currently selected item
 	autoResizeGroup->setExclusive(false);
@@ -242,40 +279,74 @@ MediaWidget::MediaWidget(QMenu *menu_, QToolBar *toolBar, KActionCollection *col
 		this, SLOT(autoResizeTriggered(QAction*)));
 
 	action = new QWidgetAction(autoResizeGroup);
-	action->setText(i18nc("automatic resize", "Off"));
+	action->setText(i18nc("Video size", "Automatic"));
 	action->setCheckable(true);
 	action->setData(0);
 	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_off"), action));
 
 	action = new QWidgetAction(autoResizeGroup);
-	action->setText(i18nc("automatic resize", "Original Size"));
+	action->setText(i18nc("Video size", "25%"));
 	action->setCheckable(true);
-	action->setData(1);
+	action->setData(25);
+	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_double"), action));
+
+	action = new QWidgetAction(autoResizeGroup);
+	action->setText(i18nc("Video size", "50%"));
+	action->setCheckable(true);
+	action->setData(50);
+	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_double"), action));
+
+
+	action = new QWidgetAction(autoResizeGroup);
+	action->setText(i18nc("Video size", "75%"));
+	action->setCheckable(true);
+	action->setData(75);
+
+	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_double"), action));
+	action = new QWidgetAction(autoResizeGroup);
+	action->setText(i18nc("Video size", "Original Size"));
+	action->setCheckable(true);
+	action->setData(100);
 	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_original"), action));
 
 	action = new QWidgetAction(autoResizeGroup);
-	action->setText(i18nc("automatic resize", "Double Size"));
+	action->setText(i18nc("Video size", "150%"));
 	action->setCheckable(true);
-	action->setData(2);
+	action->setData(150);
 	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_double"), action));
 
-	int autoResizeFactor =
+	action = new QWidgetAction(autoResizeGroup);
+	action->setText(i18nc("Video size", "200%"));
+	action->setCheckable(true);
+	action->setData(200);
+	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_double"), action));
+
+	action = new QWidgetAction(autoResizeGroup);
+	action->setText(i18nc("Video size", "250%"));
+	action->setCheckable(true);
+	action->setData(250);
+	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_double"), action));
+
+	action = new QWidgetAction(autoResizeGroup);
+	action->setText(i18nc("Video size", "300%"));
+	action->setCheckable(true);
+	action->setData(300);
+	autoResizeMenu->addAction(collection->addAction(QLatin1String("controls_autoresize_double"), action));
+
+	autoResizeFactor =
 		KSharedConfig::openConfig()->group("MediaObject").readEntry("AutoResizeFactor", 0);
 
-	switch (autoResizeFactor) {
-	case 1:
-		automaticResize = OriginalSize;
-		autoResizeGroup->actions().at(1)->setChecked(true);
-		break;
-	case 2:
-		automaticResize = DoubleSize;
-		autoResizeGroup->actions().at(2)->setChecked(true);
-		break;
-	default:
-		automaticResize = ResizeOff;
+	if (autoResizeFactor <= 300) {
+		for (int i = 0; i < autoResizeGroup->actions().size(); i++) {
+			if (autoResizeGroup->actions().at(i)->data().toInt() == autoResizeFactor) {
+				autoResizeGroup->actions().at(i)->setChecked(true);
+				break;
+			}
+		}
+	} else {
 		autoResizeGroup->actions().at(0)->setChecked(true);
-		break;
 	}
+	setVideoSize();
 
 	videoMenu->addMenu(autoResizeMenu);
 
@@ -405,21 +476,6 @@ MediaWidget::~MediaWidget()
 	KSharedConfig::openConfig()->group("MediaObject").writeEntry("Volume", volumeSlider->value());
 	KSharedConfig::openConfig()->group("MediaObject").writeEntry("Deinterlace",
 		deinterlaceAction->isChecked());
-
-	int autoResizeFactor = 0;
-
-	switch (automaticResize) {
-	case ResizeOff:
-		autoResizeFactor = 0;
-		break;
-	case OriginalSize:
-		autoResizeFactor = 1;
-		break;
-	case DoubleSize:
-		autoResizeFactor = 2;
-		break;
-	}
-
 	KSharedConfig::openConfig()->group("MediaObject").writeEntry("AutoResizeFactor", autoResizeFactor);
 }
 
@@ -806,12 +862,24 @@ void MediaWidget::aspectRatioChanged(QAction *action)
 	bool ok;
 	unsigned int aspectRatio_ = action->data().toInt(&ok);
 
-	if (ok && aspectRatio_ <= AspectRatioWidget) {
+	if (ok && aspectRatio_ <= AspectRatio239_100) {
 		backend->setAspectRatio(static_cast<AspectRatio>(aspectRatio_));
+		setVideoSize();
+
 		return;
 	}
 
-	qCWarning(logMediaWidget, "Internal error");
+	qCWarning(logMediaWidget, "internal error");
+}
+
+void MediaWidget::setVideoSize()
+{
+	float scale = autoResizeFactor / 100.0;
+
+	if (scale > 3.4 || scale < 0)
+		scale = 0;
+
+	backend->resizeToVideo(scale);
 }
 
 void MediaWidget::autoResizeTriggered(QAction *action)
@@ -821,25 +889,12 @@ void MediaWidget::autoResizeTriggered(QAction *action)
 	}
 
 	bool ok = false;
-	int autoResizeFactor = action->data().toInt(&ok);
+	autoResizeFactor = action->data().toInt(&ok);
 
-	if (ok) {
-		switch (autoResizeFactor) {
-		case 0:
-			automaticResize = ResizeOff;
-			return;
-		case 1:
-			automaticResize = OriginalSize;
-			emit resizeToVideo(automaticResize);
-			return;
-		case 2:
-			automaticResize = DoubleSize;
-			emit resizeToVideo(automaticResize);
-			return;
-		}
-	}
-
-	qCWarning(logMediaWidget, "Internal error");
+	if (ok)
+		setVideoSize();
+	else
+		qCWarning(logMediaWidget, "internal error");
 }
 
 void MediaWidget::pausedChanged(bool paused)
@@ -1351,9 +1406,7 @@ void MediaWidget::anglesChanged()
 
 void MediaWidget::videoSizeChanged()
 {
-	if (automaticResize != ResizeOff) {
-		emit resizeToVideo(automaticResize);
-	}
+	setVideoSize();
 }
 
 JumpToPositionDialog::JumpToPositionDialog(MediaWidget *mediaWidget_) : QDialog(mediaWidget_),
